@@ -87,6 +87,7 @@ class BaseBenchmark(ABC):
                  metric_names: Dict[str, str],
                  num_labels: Optional[int] = None,
                  id2label: Optional[List[str]] = None,
+                 label_synonyms: Optional[List[List[str]]] = None,
                  evaluate_train: bool = False,
                  cache_dir: str = '.benchmark_models',
                  learning_rate: float = 2e-5,
@@ -114,8 +115,15 @@ class BaseBenchmark(ABC):
         self.multilabel = multilabel
         self.split_point = split_point
         self.verbose = verbose
+        self.label_synonyms = label_synonyms
         if self.id2label is not None:
-            self.label2id = {label: id for id, label in enumerate(id2label)}
+            if label_synonyms is not None:
+                self.label2id = {label: id for id, lbl in enumerate(id2label)
+                                 for label_syns in label_synonyms
+                                 for label in label_syns
+                                 if lbl in label_syns}
+            else:
+                self.label2id = {lbl: id for id, lbl in enumerate(id2label)}
         else:
             self.label2id = None
         if verbose:
@@ -215,7 +223,9 @@ class BaseBenchmark(ABC):
         # Ensure that the framework is installed
         try:
             if framework == 'pytorch':
-                import torch  # noqa
+                import torch
+                import torch.nn as nn
+                from torch.nn import Parameter
             elif framework == 'tensorflow':
                 import tensorflow  # noqa
             elif framework == 'jax':
@@ -240,8 +250,8 @@ class BaseBenchmark(ABC):
 
             if task == 'fill-mask':
                 params = dict(num_labels=self.num_labels,
-                              label2id=self.label2id,
-                              id2label=self.id2label)
+                              id2label=self.id2label,
+                              label2id=self.label2id)
             else:
                 params = dict()
 
@@ -253,9 +263,124 @@ class BaseBenchmark(ABC):
                 model = model_cls.from_pretrained(model_id,
                                                   config=config,
                                                   cache_dir=self.cache_dir)
+
+                # Get the `label2id` and `id2label` conversions from the model
+                # config
+                try:
+                    model_label2id = dict(model.config.label2id)
+                except AttributeError:
+                    model_label2id = None
+                try:
+                    try:
+                        model_num_labels = len(model.config.id2label)
+                        if not isinstance(model.config.id2label, list):
+                            model_id2label = dict(model.config.id2label)
+                        else:
+                            model_id2label = model.config.id2label
+                        model_id2label = [model_id2label[idx]
+                                          for idx in range(model_num_labels)]
+                    except IndexError:
+                        raise InvalidBenchmark('There is a gap in the '
+                                               'indexing dictionary of the '
+                                               'model.')
+                except AttributeError:
+                    model_id2label = None
+
+                # If one of `label2id` or `id2label` exists in the model
+                # config, then define the other one from it
+                if model_label2id is not None and model_id2label is None:
+                    model_id2label = [label for label in model_label2id.keys()]
+                    model.config.id2label = model_id2label
+                if model_label2id is None and model_id2label is not None:
+                    model_label2id = {lbl: id
+                                      for id, lbl in enumerate(model_id2label)}
+                    model.config.label2id = model_label2id
+
+                # If the model does not have `label2id` or `id2label`
+                # conversions, then use the defaults
+                if model_label2id is None and model_id2label is None:
+                    model.config.label2id = self.label2id
+                    model.config.id2label = self.id2label
+
+                # If the model *does* have conversions, then ensure that it can
+                # deal with all the labels in the default conversions. This
+                # ensures that we can smoothly deal with labels that the model
+                # have not been trained on (it will just always get those
+                # labels wrong)
+                else:
+                    for label in self.id2label:
+                        if label not in model_id2label:
+                            model_id2label.append(label)
+
+                    if self.label_synonyms is None:
+                        synonyms = [[label] for label in model_id2label]
+                    else:
+                        synonyms = self.label_synonyms
+
+                    # Add all the synonyms of the labels into the label2id
+                    # conversion dictionary
+                    model_label2id = {label: id
+                                      for id, lbl in enumerate(model_id2label)
+                                      for label_syns in synonyms
+                                      for label in label_syns
+                                      if lbl in label_syns}
+
+                    # Get the old id2label conversion
+                    if not isinstance(model.config.id2label, list):
+                        old_model_id2label = dict(model.config.id2label)
+                    else:
+                        old_model_id2label = model.config.id2label
+
+                    # This changes the classification layer in the finetuned
+                    # model to be consistent with all the labels in the
+                    # dataset. If the model was previously finetuned on a
+                    # dataset which left out a label, say, then that label will
+                    # be inserted in the model architecture here, but without
+                    # the model ever predicting it. This will allow the model
+                    # to be benchmarked on such datasets, however.
+                    # NOTE: This only works on classification tasks. This code
+                    #       needs to be rewritten when we add other types of
+                    #       tasks.
+                    # NOTE: Only works for pytorch models at the moment
+                    if (len(model_id2label) > len(old_model_id2label)
+                            and framework == 'pytorch'):
+
+                        # Count the number of new labels to add to the model
+                        num_new_labels = (len(model_id2label) -
+                                          len(old_model_id2label))
+
+                        # Load the weights from the model's current
+                        # classification layer
+                        clf_weight = model.classifier.weight.data
+
+                        # Create the new weights, which have zeros at all the
+                        # new entries
+                        zeros = torch.zeros(num_new_labels, config.hidden_size)
+                        new_clf_weight = torch.cat((clf_weight, zeros), dim=0)
+                        new_clf_weight = Parameter(new_clf_weight)
+
+                        # Create the new classification layer
+                        new_clf = nn.Linear(config.hidden_size,
+                                            len(model_id2label))
+
+                        # Assign the new weights to the new classification
+                        # layer, and replace the old classification layer with
+                        # this one
+                        new_clf.weight = new_clf_weight
+                        model.classifier = new_clf
+
+                        # Update the number of labels the model think it has.
+                        # This is required to avoid exceptions when evaluating
+                        model.config.num_labels = len(model_id2label)
+                        model.num_labels = len(model_id2label)
+
+                    # Update the model's own conversions with the new ones
+                    model.config.id2label = model_id2label
+                    model.config.label2id = model_label2id
+
             except (OSError, ValueError):
                 raise InvalidBenchmark(f'The model {model_id} could not be '
-                                       f'loaded from the HuggingFace hub.')
+                                       f'loaded from the HuggingFace hub')
 
             # If the model is a subclass of a RoBERTa model then we have to add
             # a prefix space to the tokens, by the way the model is
@@ -503,8 +628,8 @@ class BaseBenchmark(ABC):
         # Get bootstrap sample indices
         if finetune or self.evaluate_train:
             train_bidxs = rng.integers(0, len(train),
-                                       size=(num_finetunings, len(train)))
-        test_bidxs = rng.integers(0, len(test), size=(10, len(test)))
+                                       size=(num_finetunings - 1, len(train)))
+        test_bidxs = rng.integers(0, len(test), size=(9, len(test)))
 
         if framework in ['pytorch', 'tensorflow', 'jax']:
 
@@ -639,14 +764,25 @@ class BaseBenchmark(ABC):
                         trainer.args = training_args
 
                         # Garbage collection, to avoid memory issues
-                        del model, model_dict
+                        try:
+                            del model, model_dict
+                        except UnboundLocalError:
+                            try:
+                                del model
+                            except UnboundLocalError:
+                                pass
                         gc.collect()
 
             self._log_metrics(metrics, model_id=model_id, finetuned=finetune)
 
             # Garbage collection, to avoid memory issues
-            del model, model_dict
-            del train, test
+            try:
+                del model, model_dict
+            except UnboundLocalError:
+                try:
+                    del model
+                except UnboundLocalError:
+                    pass
             gc.collect()
 
             return metrics
@@ -699,10 +835,16 @@ class BaseBenchmark(ABC):
                 all_train_metrics.append(train_metrics)
                 metrics['train'] = all_train_metrics
 
-            self._log_metrics(metrics, model_id=model_id)
+            self._log_metrics(metrics, model_id=model_id, finetuned=False)
 
             # Garbage collection, to avoid memory issues
-            del model, model_dict
+            try:
+                del model, model_dict
+            except UnboundLocalError:
+                try:
+                    del model
+                except UnboundLocalError:
+                    pass
             gc.collect()
 
             return metrics
